@@ -17,10 +17,13 @@
 #'   \code{\link[readr]{locale}} to create your own locale that controls things 
 #'   like the default time zone, encoding, decimal mark, big mark, and day/month
 #'   names.
+#' @param na character Vector of strings to interpret as missing values. Set 
+#'   this option to character() to indicate no missing values.
+#' @param ... Further named arguments currently passed to \code{read_csv()}.
 #'   
 #' @return \code{read_csi_dat()} returns a \code{tibble::tibble} object.
 #' @export
-#' @references \url{https://www.r4photobiology.info} \url{https://www.campbellsci.eu/}
+#' @references \url{https://www.campbellsci.eu/}
 #' 
 #' @note This function is not useful for .DAT and .PRN files from old CSI
 #'   loggers and software. Those were simple files, lacking metadata, which was
@@ -31,7 +34,9 @@ read_csi_dat <- function(file,
                          label = NULL,
                          data_skip = 0, 
                          n_max = Inf, 
-                         locale = readr::default_locale()) {
+                         locale = readr::default_locale(),
+                         na = c("", "NA", "NAN"),
+                         ...) {
 
   label.file <- paste("File: ", basename(file), sep = "")
   if (is.null(label)) {
@@ -41,14 +46,17 @@ read_csi_dat <- function(file,
   }
   
   file_header <- readr::read_lines(file, n_max = 4, skip = 0)
-  head_line <-  scan(text = file_header[1L], what = character(), sep = ",")
+  head_line <-  scan(text = file_header[1L], what = character(), 
+                     sep = ",", quiet = TRUE)
   head_line = paste(head_line, collapse = "\t")
-  col_names <- scan(text = file_header[2L], what = character(), sep = ",")
-  units <- scan(text = file_header[3L], what = character(), sep = ",", encoding = "UTF-8")
+  col_names <- scan(text = file_header[2L], what = character(), 
+                    sep = ",", quiet = TRUE)
+  units <- scan(text = file_header[3L], what = character(), 
+                sep = ",", encoding = "UTF-8", quiet = TRUE)
   units <- sub("^$", "NA", units)
   qty <- scan(file, 
               what = character(), nlines = 1, skip = 3,
-              sep = ",")
+              sep = ",", quiet = TRUE)
   metadata <- paste(col_names, units, qty, sep = "\t", collapse = "\n")
   comment.txt <- paste(label, head_line, metadata, sep = "\n---\n")
   # readr::read_csv automatically recognizes dates as well as numeric
@@ -58,7 +66,9 @@ read_csi_dat <- function(file,
                     skip = 4 + data_skip, 
                     n_max = n_max, 
                     col_names = col_names,
-                    col_types = readr::cols())
+                    col_types = readr::cols(),
+                    progress = FALSE,
+                    ...)
 
   attr(z, "file.header") <- file_header
   comment(z) <- comment.txt
